/*
 * Primitive.cpp
 *
 *  Created on: Apr 16, 2013
 *      Author: Jan Travnicek
 */

#include "Primitive.h"
#include "Integer.h"
#include "Character.h"
#include "String.h"
#include "Unsigned.h"
#include "Bool.h"
#include <core/xmlApi.hpp>

namespace primitive {

void Primitive::inc ( ) {
	this->operator ++ ( );
}

Primitive primitiveFrom ( int number ) {
	return Primitive {
			   Integer {
				   number
			   }
	};
}

Primitive primitiveFrom ( char character ) {
	return Primitive {
			   Character {
				   character
			   }
	};
}

Primitive primitiveFrom ( const char * string ) {
	return primitiveFrom ( ( std::string ) string );
}

Primitive primitiveFrom ( std::string string ) {
	return Primitive {
			   String {
				   std::move ( string )
			   }
	};
}

Primitive primitiveFrom ( unsigned number ) {
	return Primitive {
			   Unsigned {
				   number
			   }
	};
}

Primitive primitiveFrom ( bool value ) {
	return Primitive {
			   Bool {
				   value
			   }
	};
}

} /* namespace primitive */

namespace alib {

auto PrimitiveDeleter = xmlApi < primitive::Primitive >::InputContextDeleter ( );
}
